import { defineComponent } from 'vue';
import * as common from 'schema-based-json-editor';
import JSON5 from 'json5';
import { Icon } from './icon';
import { Optional } from './optional';
import { Description } from './description';
import { anyEditorTemplateHtml } from './variables';
export var AnyEditor = defineComponent({
    props: {
        schema: {
            type: Object,
            required: true,
        },
        initialValue: null,
        title: [String, Number],
        theme: {
            type: Object,
            required: true,
        },
        icon: {
            type: Object,
            required: true,
        },
        locale: {
            type: Object,
            required: true,
        },
        readonly: Boolean,
        required: Boolean,
        hasDeleteButton: {
            type: Boolean,
            required: true,
        },
        monacoEditor: Object,
    },
    data: function () {
        return {
            value: undefined,
            monacoCodeEditor: undefined,
            buttonGroupStyle: common.buttonGroupStyleString,
        };
    },
    computed: {
        className: function () {
            var rowClass = this.theme.row;
            return this.schema.className ? rowClass + ' ' + this.schema.className : rowClass;
        },
        titleToShow: function () {
            return common.getTitle(this.title, this.schema.title);
        },
        isReadOnly: function () {
            return this.readonly || this.schema.readonly;
        },
        hasDeleteButtonFunction: function () {
            return this.hasDeleteButton && !this.isReadOnly;
        },
    },
    methods: {
        toggleOptional: function () {
            this.value = common.toggleOptional(this.value, this.schema, this.initialValue);
            this.$emit('update-value', { value: this.value, isValid: true });
        }
    },
    beforeMount: function () {
        this.value = common.getDefaultValue(this.required, this.schema, this.initialValue);
    },
    mounted: function () {
        var _this = this;
        if (this.monacoEditor && this.$refs.monacoEditor) {
            this.monacoCodeEditor = this.monacoEditor.create(this.$refs.monacoEditor, {
                value: 'export default ' + JSON5.stringify(this.value, null, 2),
                language: 'javascript',
                minimap: { enabled: false },
                lineNumbers: 'off'
            });
            var timer_1;
            this.monacoCodeEditor.onDidChangeModelContent(function () {
                clearTimeout(timer_1);
                timer_1 = setTimeout(function () {
                    try {
                        var value = _this.monacoCodeEditor.getValue();
                        if (value.indexOf('export default') === 0) {
                            value = value.substring('export default'.length);
                        }
                        _this.value = JSON5.parse(value);
                        _this.$emit('update-value', { value: _this.value, isValid: true });
                    }
                    catch (_a) {
                        // do nothing
                    }
                }, 500);
            });
        }
    },
    components: {
        icon: Icon,
        optional: Optional,
        description: Description,
    },
    render: anyEditorTemplateHtml,
});
