import { defineComponent } from 'vue';
import * as common from 'schema-based-json-editor';
import { Select2 } from "select2-vue-component";
import { Icon } from './icon';
import { Optional } from './optional';
import { Description } from './description';
import { numberEditorTemplateHtml } from './variables';
export var NumberEditor = defineComponent({
    render: numberEditorTemplateHtml,
    components: {
        icon: Icon,
        optional: Optional,
        description: Description,
        select2: Select2,
    },
    props: {
        schema: {
            type: Object,
            required: true,
        },
        initialValue: Number,
        title: [String, Number],
        theme: {
            type: Object,
            required: true,
        },
        icon: {
            type: Object,
            requried: true,
        },
        locale: {
            type: Object,
            required: true,
        },
        readonly: Boolean,
        required: Boolean,
        hasDeleteButton: {
            type: Boolean,
            required: true,
        },
        noSelect2: {
            type: Boolean,
            required: true,
        },
    },
    data: function () {
        return {
            value: 0,
            errorMessage: '',
            buttonGroupStyle: common.buttonGroupStyleString,
        };
    },
    beforeMount: function () {
        this.value = common.getDefaultValue(this.required, this.schema, this.initialValue);
        this.validate();
        this.$emit('update-value', { value: this.value, isValid: !this.errorMessage });
    },
    computed: {
        useInput: function () {
            return this.value !== undefined && (this.schema.enum === undefined || this.isReadOnly);
        },
        useSelect: function () {
            return this.value !== undefined && (this.schema.enum !== undefined && !this.isReadOnly);
        },
        useSelect2Component: function () {
            return this.useSelect && !this.noSelect2 && this.schema.format !== 'select' && this.schema.format !== 'radiobox';
        },
        useSelectComponent: function () {
            return this.useSelect && (this.schema.format === 'select' || this.noSelect2);
        },
        useRadioBoxComponent: function () {
            return this.useSelect && this.schema.format === 'radiobox';
        },
        isReadOnly: function () {
            return this.readonly || this.schema.readonly;
        },
        hasDeleteButtonFunction: function () {
            return this.hasDeleteButton && !this.isReadOnly;
        },
        titleToShow: function () {
            return common.getTitle(this.title, this.schema.title);
        },
        options: function () {
            return common.getOptions(this.schema);
        },
        className: function () {
            var rowClass = this.errorMessage ? this.theme.errorRow : this.theme.row;
            return this.schema.className ? rowClass + ' ' + this.schema.className : rowClass;
        },
        step: function () {
            return common.getNumberStep(this.schema);
        },
    },
    methods: {
        onChange: function (e) {
            this.value = this.schema.type === 'integer' ? common.toInteger(e.target.value) : common.toNumber(e.target.value);
            this.validate();
            this.$emit('update-value', { value: this.value, isValid: !this.errorMessage });
        },
        updateSelection: function (value) {
            this.value = value;
            this.validate();
            this.$emit('update-value', { value: this.value, isValid: !this.errorMessage });
        },
        toggleOptional: function () {
            this.value = common.toggleOptional(this.value, this.schema, this.initialValue);
            this.validate();
            this.$emit('update-value', { value: this.value, isValid: !this.errorMessage });
        },
        validate: function () {
            this.errorMessage = common.getErrorMessageOfNumber(this.value, this.schema, this.locale);
        },
    }
});
